JsDoc Reference - links.Point2d

Class Index | File Index

## Classes

- _global_
- links.Filter
- links.Graph3d
- links.Graph3d.Camera
- links.Point2d
- links.Point3d
- links.Slider
- links.StepNumber

# Class links.Point2d

Point2d
Defined in: graph3d.js.

Class Summary
Constructor Attributes | Constructor Name and Description
--- | ---
| links.Point2d(x, y)

Class Detail
links.Point2d(x, y)

Parameters:
x
y

Documentation generated by JsDoc Toolkit 2.3.2 on Thu May 03 2012 16:42:47 GMT+0200 (CEST)